################################################################
#Thompson & Birkhead, 2020, Avian egg collections: museum collection bias driven by shape and size
################################################################
rm(list = ls())
#load csv file
field.vs.museum <- read.csv("ThompsonandBirkhead.2020.dataset.csv")
str(field.vs.museum)

#subsetting data
R <- subset(field.vs.museum, species =="alca.torda")
CG <- subset(field.vs.museum, species =="uria.aalge")
NF <- subset(field.vs.museum, species =="fulmurus.glacialis")
NF.remove.outlier <- subset(NF, Pointedness <= 0.60)
field.only <- subset(field.vs.museum, collection.type =="field")
museum.only <- subset(field.vs.museum, collection.type =="field")

R.field <- subset(R, collection.type =="field")
R.museum <- subset(R, collection.type =="museum")
CG.field <- subset(CG, collection.type =="field")
CG.museum <- subset(CG, collection.type =="museum")
NF.field <- subset(NF, collection.type =="field")
NF.museum <- subset(NF, collection.type =="museum")
NF.outlier.removed.field <- subset(NF.remove.outlier, collection.type =="field")
CG.Skomer2014 <- subset(CG, separated.groupings =="Skomer.Island.2014")
CG.Skomer2015 <- subset(CG, separated.groupings =="Skomer.Island.2015")
CG.Skomer2016 <- subset(CG, separated.groupings =="Skomer.Island.2016")
CG.Skomer2017 <- subset(CG, separated.groupings =="Skomer.Island.2017")
CG.Skomer2018 <- subset(CG, separated.groupings =="Skomer.Island.2018")
CG.Pembrokeshire <- subset(CG, separated.groupings =="Pembrokeshire.museum")
R.Skomer2015 <- subset(R, separated.groupings =="Skomer Island 2015")
R.Skomer2016 <- subset(R, separated.groupings =="Skomer Island 2016")
R.Skomer2017 <- subset(R, separated.groupings =="Skomer Island 2017")
R.Skomer2018 <- subset(R, separated.groupings =="Skomer Island 2018")
R.Pembrokeshire <- subset(R, separated.groupings =="Pembrokeshire.museum")

R.PembrokeshirevsSkomer2015 <-subset(R, separated.groupings %in% c("Skomer Island 2015", "Pembrokekshire.museum"))
R.PembrokeshirevsSkomer2016 <-subset(R, separated.groupings %in% c("Skomer Island 2016", "Pembrokekshire.museum"))
R.PembrokeshirevsSkomer2017 <-subset(R, separated.groupings %in% c("Skomer Island 2017", "Pembrokekshire.museum"))
R.PembrokeshirevsSkomer2018 <-subset(R, separated.groupings %in% c("Skomer Island 2018", "Pembrokekshire.museum"))

CG.PembrokekshirevsSkomer2014 <-subset(CG, separated.groupings %in% c("Skomer.Island.2014", "Pembrokekshire.museum"))
CG.PembrokekshirevsSkomer2015 <-subset(CG, separated.groupings %in% c("Skomer.Island.2015", "Pembrokekshire.museum"))
CG.PembrokekshirevsSkomer2016 <-subset(CG, separated.groupings %in% c("Skomer.Island.2016", "Pembrokekshire.museum"))
CG.PembrokekshirevsSkomer2017 <-subset(CG, separated.groupings %in% c("Skomer.Island.2017", "Pembrokekshire.museum"))
CG.PembrokekshirevsSkomer2018 <-subset(CG, separated.groupings %in% c("Skomer.Island.2014", "Pembrokekshire.museum"))

#kernel density plots
library(ggplot2)
library(extrafont)
loadfonts()
Sys.setenv(R_GSCMD = "C:\\Program Files\\gs\\gs9.50\\bin\\gswin64c.exe")

#Common Guillemots
#Pointedness
CG.Pointedness.kernel<-ggplot(CG, aes(x=Pointedness, colour = collection.type,
                                      fill=collection.type)) +
  geom_density(aes(y=..scaled..),alpha=0.4) + 
  labs(x = "", y = "density") +
  xlim(0.49, 0.70) +
  theme(panel.border = element_rect(colour = "black", fill=NA, size=0.2),
        panel.background = element_blank(),
        panel.grid.major = element_line(size = 0.5, linetype = 'solid',
                                        colour = "lightgray"),
        panel.grid.minor = element_line(size = 0.5, linetype = 'solid',
        colour = "lightgray"),
        legend.position = "none",
        axis.text = element_text(size = 9, colour = "black"),
        text=element_text(family = "Calibri"),
        axis.title.y = element_text(margin = margin(t = 0, r = 10, b = 0, l = 0))) 
CG.Pointedness.kernel

# Add mean lines
library(plyr)
CG.Pointedness.mean <- ddply(CG, "collection.type", summarise, grp.mean=mean(Pointedness))
final.CG.Pointedness.kernel <- CG.Pointedness.kernel+geom_vline(data=CG.Pointedness.mean, aes(xintercept=grp.mean, color=collection.type),
             linetype="dashed")
final.CG.Pointedness.kernel

#Elongation
CG.Elongation.kernel<-ggplot(CG, aes(x=Elongation, colour = collection.type,
                                     fill=collection.type)) +
  geom_density(aes(y=..scaled..),alpha=0.4) +
  labs(x = "", y = "density") +
  xlim(1.25, 2) +
  theme(panel.border = element_rect(colour = "black", fill=NA, size=0.2),
        panel.background = element_blank(),
        panel.grid.major = element_line(size = 0.5, linetype = 'solid',
                                        colour = "lightgray"),
        panel.grid.minor = element_line(size = 0.5, linetype = 'solid',
                                        colour = "lightgray"),
        legend.position = "none",
        axis.text = element_text(size = 9, colour = "black"),
        text=element_text(family = "Calibri"),
        axis.title.y = element_text(margin = margin(t = 0, r = 10, b = 0, l = 0))) 
CG.Elongation.kernel
# Add mean lines
library(plyr)
CG.Elongation.mean <- ddply(CG, "collection.type", summarise, grp.mean=mean(Elongation))
final.CG.Elongation.kernel <- CG.Elongation.kernel+geom_vline(data=CG.Elongation.mean, aes(xintercept=grp.mean, color=collection.type),
                                 linetype="dashed")
final.CG.Elongation.kernel
#PolarAsymmetry
CG.PolarAsymmetry.kernel<-ggplot(CG, aes(x=PolarAsymmetry, colour = collection.type,
                                         fill=collection.type)) +
  geom_density(aes(y=..scaled..),alpha=0.4) +
  labs(x ="", y = "density") +
  xlim(1, 4) +
  theme(panel.border = element_rect(colour = "black", fill=NA, size=0.2),
        panel.background = element_blank(),
        panel.grid.major = element_line(size = 0.5, linetype = 'solid',
                                        colour = "lightgray"),
        panel.grid.minor = element_line(size = 0.5, linetype = 'solid',
                                        colour = "lightgray"),
        legend.position = "none",
        axis.text = element_text(size = 9, colour = "black"),
        text=element_text(family = "Calibri"),
        axis.title.y = element_text(margin = margin(t = 0, r = 10, b = 0, l = 0))) 
CG.PolarAsymmetry.kernel
# Add mean lines
library(plyr)
CG.PolarAsymmetry.mean <- ddply(CG, "collection.type", summarise, grp.mean=mean(PolarAsymmetry))
final.CG.PolarAsymmetry.kernel <- CG.PolarAsymmetry.kernel+geom_vline(data=CG.PolarAsymmetry.mean, aes(xintercept=grp.mean, color=collection.type),
                                linetype="dashed")
final.CG.PolarAsymmetry.kernel
#volcc
CG.volcc.kernel<-ggplot(CG, aes(x=volcc, colour = collection.type,
                                fill=collection.type)) +
  geom_density(aes(y=..scaled..),alpha=0.4) +
  labs(x = "", y = "density") +
  xlim(50, 130) +
  theme(panel.border = element_rect(colour = "black", fill=NA, size=0.2),
        panel.background = element_blank(),
        panel.grid.major = element_line(size = 0.5, linetype = 'solid',
                                        colour = "lightgray"),
        panel.grid.minor = element_line(size = 0.5, linetype = 'solid',
                                        colour = "lightgray"),
        legend.position = "none",
        axis.text = element_text(size = 9, colour = "black"),
        text=element_text(family = "Calibri"),
        axis.title.y = element_text(margin = margin(t = 0, r = 10, b = 0, l = 0))) 
CG.volcc.kernel
# Add mean lines
library(plyr)
CG.volcc.mean <- ddply(CG, "collection.type", summarise, grp.mean=mean(volcc))
final.CG.volcc.kernel <- CG.volcc.kernel+geom_vline(data=CG.volcc.mean, aes(xintercept=grp.mean, color=collection.type),
                                linetype="dashed")
final.CG.volcc.kernel

#Razorbill
#Pointedness
R.Pointedness.kernel<-ggplot(R, aes(x=Pointedness, colour = collection.type,
                                    fill=collection.type)) +
  geom_density(aes(y=..scaled..),alpha=0.4) +
  labs(y = "density") +
  xlim(0.49, 0.70) +
  theme(panel.border = element_rect(colour = "black", fill=NA, size=0.2),
        panel.background = element_blank(),
        panel.grid.major = element_line(size = 0.5, linetype = 'solid',
                                        colour = "lightgray"),
        panel.grid.minor = element_line(size = 0.5, linetype = 'solid',
                                        colour = "lightgray"),
        legend.position = "none",
        axis.text = element_text(size = 9, colour = "black"),
        text=element_text(family = "Calibri"),
        axis.title.y = element_text(margin = margin(t = 0, r = 10, b = 0, l = 0))) 
R.Pointedness.kernel
# Add mean lines
library(plyr)
R.Pointedness.mean <- ddply(R, "collection.type", summarise, grp.mean=mean(Pointedness))
final.R.Pointedness.kernel <- R.Pointedness.kernel+geom_vline(data=R.Pointedness.mean, aes(xintercept=grp.mean, color=collection.type),
                                 linetype="dashed")
final.R.Pointedness.kernel
#Elongation
R.Elongation.kernel<-ggplot(R, aes(x=Elongation, colour = collection.type,
                                   fill=collection.type)) +
  geom_density(aes(y=..scaled..),alpha=0.4) +
  labs(y = "density") +
  xlim(1.25, 2.0) +
  theme(panel.border = element_rect(colour = "black", fill=NA, size=0.2),
        panel.background = element_blank(),
        panel.grid.major = element_line(size = 0.5, linetype = 'solid',
                                        colour = "lightgray"),
        panel.grid.minor = element_line(size = 0.5, linetype = 'solid',
                                        colour = "lightgray"),
        legend.position = "none",
        axis.text = element_text(size = 9, colour = "black"),
        text=element_text(family = "Calibri"),
        axis.title.y = element_text(margin = margin(t = 0, r = 10, b = 0, l = 0))) 
R.Elongation.kernel
# Add mean lines
library(plyr)
R.Elongation.mean <- ddply(R, "collection.type", summarise, grp.mean=mean(Elongation))
final.R.Elongation.kernel <- R.Elongation.kernel+geom_vline(data=R.Elongation.mean, aes(xintercept=grp.mean, color=collection.type),
                                linetype="dashed")
final.R.Elongation.kernel
#PolarAsymmetry
R.PolarAsymmetry.kernel<-ggplot(R, aes(x=PolarAsymmetry, colour = collection.type,
                                       fill=collection.type)) +
  geom_density(aes(y=..scaled..),alpha=0.4) +
  labs(y = "density") +
  xlim(1, 4) +
  theme(panel.border = element_rect(colour = "black", fill=NA, size=0.2),
        panel.background = element_blank(),
        panel.grid.major = element_line(size = 0.5, linetype = 'solid',
                                        colour = "lightgray"),
        panel.grid.minor = element_line(size = 0.5, linetype = 'solid',
                                        colour = "lightgray"),
        legend.position = "none",
        axis.text = element_text(size = 9, colour = "black"),
        text=element_text(family = "Calibri"),
        axis.title.y = element_text(margin = margin(t = 0, r = 10, b = 0, l = 0))) 
R.PolarAsymmetry.kernel
# Add mean lines
library(plyr)
R.PolarAsymmetry.mean <- ddply(R, "collection.type", summarise, grp.mean=mean(PolarAsymmetry))
final.R.PolarAsymmetry.kernel <- R.PolarAsymmetry.kernel+geom_vline(data=R.PolarAsymmetry.mean, aes(xintercept=grp.mean, color=collection.type),
                                    linetype="dashed")
final.R.PolarAsymmetry.kernel
#volcc
R.volcc.kernel<-ggplot(R, aes(x=volcc, colour = collection.type,
                              fill=collection.type)) +
  geom_density(aes(y=..scaled..),alpha=0.4) +
  labs(x = "Egg Volume (cc)", y = "density") +
  xlim(50, 130) +
  theme(panel.border = element_rect(colour = "black", fill=NA, size=0.2),
        panel.background = element_blank(),
        panel.grid.major = element_line(size = 0.5, linetype = 'solid',
                                        colour = "lightgray"),
        panel.grid.minor = element_line(size = 0.5, linetype = 'solid',
                                        colour = "lightgray"),
        legend.position = "none",
        axis.text = element_text(size = 9, colour = "black"),
        text=element_text(family = "Calibri"),
        axis.title.y = element_text(margin = margin(t = 0, r = 10, b = 0, l = 0))) 
R.volcc.kernel
# Add mean lines
library(plyr)
R.volcc.mean <- ddply(R, "collection.type", summarise, grp.mean=mean(volcc))
final.R.volcc.kernel <- R.volcc.kernel+geom_vline(data=R.volcc.mean, aes(xintercept=grp.mean, color=collection.type),
                           linetype="dashed")
final.R.volcc.kernel

#Northern Fulmar
#Pointedness
NF.Pointedness.kernel<-ggplot(NF, aes(x=Pointedness, colour = collection.type,
                                      fill=collection.type)) +
  geom_density(aes(y=..scaled..),alpha=0.4) +
  labs(x ="", y = "density") +
  xlim(0.49, 0.70) +
  theme(panel.border = element_rect(colour = "black", fill=NA, size=0.2),
        panel.background = element_blank(),
        panel.grid.major = element_line(size = 0.5, linetype = 'solid',
                                        colour = "lightgray"),
        panel.grid.minor = element_line(size = 0.5, linetype = 'solid',
                                        colour = "lightgray"),
        legend.position = "none",
        axis.text = element_text(size = 9, colour = "black"),
        text=element_text(family = "Calibri"),
        axis.title.y = element_text(margin = margin(t = 0, r = 10, b = 0, l = 0))) 
NF.Pointedness.kernel
# Add mean lines
library(plyr)
NF.Pointedness.mean <- ddply(NF, "collection.type", summarise, grp.mean=mean(Pointedness))
final.NF.Pointedness.kernel <- NF.Pointedness.kernel+geom_vline(data=NF.Pointedness.mean, aes(xintercept=grp.mean, color=collection.type),
                                 linetype="dashed")
final.NF.Pointedness.kernel
#Elongation
NF.Elongation.kernel<-ggplot(NF, aes(x=Elongation, colour = collection.type,
                                     fill=collection.type)) +
  geom_density(aes(y=..scaled..),alpha=0.4) +
  labs(x = "", y = "density") +
  xlim(1.25, 2) +
  theme(panel.border = element_rect(colour = "black", fill=NA, size=0.2),
        panel.background = element_blank(),
        panel.grid.major = element_line(size = 0.5, linetype = 'solid',
                                        colour = "lightgray"),
        panel.grid.minor = element_line(size = 0.5, linetype = 'solid',
                                        colour = "lightgray"),
        legend.position = "none",
        axis.text = element_text(size = 9, colour = "black"),
        text=element_text(family = "Calibri"),
        axis.title.y = element_text(margin = margin(t = 0, r = 10, b = 0, l = 0))) 
NF.Elongation.kernel
# Add mean lines
library(plyr)
NF.Elongation.mean <- ddply(NF, "collection.type", summarise, grp.mean=mean(Elongation))
final.NF.Elongation.kernel <- NF.Elongation.kernel+geom_vline(data=NF.Elongation.mean, aes(xintercept=grp.mean, color=collection.type),
                                linetype="dashed")
final.NF.Elongation.kernel
#PolarAsymmetry
NF.PolarAsymmetry.kernel<-ggplot(NF, aes(x=PolarAsymmetry, colour = collection.type,
                                         fill=collection.type)) +
  geom_density(aes(y=..scaled..),alpha=0.4) +
  labs(x ="", y = "density") +
  xlim(1, 4) +
  theme(panel.border = element_rect(colour = "black", fill=NA, size=0.2),
        panel.background = element_blank(),
        panel.grid.major = element_line(size = 0.5, linetype = 'solid',
                                        colour = "lightgray"),
        panel.grid.minor = element_line(size = 0.5, linetype = 'solid',
                                        colour = "lightgray"),
        legend.position = "none",
        axis.text = element_text(size = 9, colour = "black"),
        text=element_text(family = "Calibri"),
        axis.title.y = element_text(margin = margin(t = 0, r = 10, b = 0, l = 0))) 
NF.PolarAsymmetry.kernel
# Add mean lines
library(plyr)
NF.PolarAsymmetry.mean <- ddply(NF, "collection.type", summarise, grp.mean=mean(PolarAsymmetry))
final.NF.PolarAsymmetry.kernel <- NF.PolarAsymmetry.kernel+geom_vline(data=NF.PolarAsymmetry.mean, aes(xintercept=grp.mean, color=collection.type),
                                    linetype="dashed")
final.NF.PolarAsymmetry.kernel
#volcc
NF.volcc.kernel<-ggplot(NF, aes(x=volcc, colour = collection.type,
                                fill=collection.type)) +
  geom_density(aes(y=..scaled..),alpha=0.4) +
  labs(x = "", y = "density") +
  xlim(50, 130) +
  theme(panel.border = element_rect(colour = "black", fill=NA, size=0.2),
        panel.background = element_blank(),
        panel.grid.major = element_line(size = 0.5, linetype = 'solid',
                                        colour = "lightgray"),
        panel.grid.minor = element_line(size = 0.5, linetype = 'solid',
                                        colour = "lightgray"),
        legend.position = "none",
        axis.text = element_text(size = 9, colour = "black"),
        text=element_text(family = "Calibri"),
        axis.title.y = element_text(margin = margin(t = 0, r = 10, b = 0, l = 0))) 
NF.volcc.kernel
# Add mean lines
library(plyr)
NF.volcc.mean <- ddply(NF, "collection.type", summarise, grp.mean=mean(volcc))
final.NF.volcc.kernel <- NF.volcc.kernel+geom_vline(data=NF.volcc.mean, aes(xintercept=grp.mean, color=collection.type),
                           linetype="dashed")
final.NF.volcc.kernel

#create final figure
library(ggpubr)

final.fig <- ggarrange(final.CG.Pointedness.kernel, final.R.Pointedness.kernel, final.NF.Pointedness.kernel,
          final.CG.Elongation.kernel, final.R.Elongation.kernel, final.NF.Elongation.kernel,
          final.CG.PolarAsymmetry.kernel, final.R.PolarAsymmetry.kernel, final.NF.PolarAsymmetry.kernel,
          final.CG.volcc.kernel, final.R.volcc.kernel, final.NF.volcc.kernel,
          ncol = 3, nrow = 4, common.legend = TRUE, legend="right") +
          theme(legend.title = element_text(family = "Calibri", size = 10),
          legend.margin = margin(0.5, 0.5, 0.5, 0.5, "cm"))
final.fig
ggsave("Fig.1.pdf", plot = final.fig, 
       device = cairo_pdf,
       dpi = 300) 


#Pointedness Mean, SD, CV

#Common Guillemot
mean(CG.field$Pointedness, na.rm=TRUE)#0.6381864
sd(CG.field$Pointedness, na.rm=TRUE) #0.01314156
(sd(CG.field$Pointedness, na.rm=TRUE)/ 
  mean(CG.field$Pointedness, na.rm=TRUE))*100 #2.059205

mean(CG.museum$Pointedness, na.rm=TRUE)#0.6441313
sd(CG.museum$Pointedness, na.rm=TRUE) #0.01434108
(sd(CG.museum$Pointedness, na.rm=TRUE)/ 
  mean(CG.museum$Pointedness, na.rm=TRUE))*100 #2.226422


#Razorbill
mean(R.field$Pointedness, na.rm=TRUE)#0.5980328
sd(R.field$Pointedness, na.rm=TRUE) #0.01488871
(sd(R.field$Pointedness, na.rm=TRUE)/ 
  mean(R.field$Pointedness, na.rm=TRUE))*100 #2.489614

mean(R.museum$Pointedness, na.rm=TRUE)#0.5990628
sd(R.museum$Pointedness, na.rm=TRUE) #0.01443732
(sd(R.museum$Pointedness, na.rm=TRUE)/ 
  mean(R.museum$Pointedness, na.rm=TRUE))*100 #2.409985


#Northern Fulmar
mean(NF.field$Pointedness, na.rm=TRUE)#0.5495852
sd(NF.field$Pointedness, na.rm=TRUE) #0.02562941
(sd(NF.field$Pointedness, na.rm=TRUE)/ 
  mean(NF.field$Pointedness, na.rm=TRUE))*100 #4.663409

mean(NF.museum$Pointedness, na.rm=TRUE)#0.5475631
sd(NF.museum$Pointedness, na.rm=TRUE) #0.0157053
(sd(NF.museum$Pointedness, na.rm=TRUE)/ 
  mean(NF.museum$Pointedness, na.rm=TRUE))*100 #2.868217

mean(NF.outlier.removed.field$Pointedness, na.rm=TRUE)#0.5471254
sd(NF.outlier.removed.field$Pointedness, na.rm=TRUE) #0.02172428
(sd(NF.outlier.removed.field$Pointedness, na.rm=TRUE)/ 
    mean(NF.outlier.removed.field$Pointedness, na.rm=TRUE))*100 #3.970621


#Elongation Mean, SD, CV

#Common Guillemot
mean(CG.field$Elongation, na.rm=TRUE)#1.644232
sd(CG.field$Elongation, na.rm=TRUE) #0.06474054
(sd(CG.field$Elongation, na.rm=TRUE)/ 
  mean(CG.field$Elongation, na.rm=TRUE))*100 #3.937434

mean(CG.museum$Elongation, na.rm=TRUE)#1.640319
sd(CG.museum$Elongation, na.rm=TRUE) #0.07643283
(sd(CG.museum$Elongation, na.rm=TRUE)/ 
  mean(CG.museum$Elongation, na.rm=TRUE))*100 #4.659631


#Razorbill
mean(R.field$Elongation, na.rm=TRUE)#1.578735
sd(R.field$Elongation, na.rm=TRUE) #0.06432558
(sd(R.field$Elongation, na.rm=TRUE)/ 
  mean(R.field$Elongation, na.rm=TRUE))*100 #4.074501

mean(R.museum$Elongation, na.rm=TRUE)#1.560425
sd(R.museum$Elongation, na.rm=TRUE) #0.06281712
(sd(R.museum$Elongation, na.rm=TRUE)/ 
  mean(R.museum$Elongation, na.rm=TRUE))*100 #4.025641


#Northern Fulmar
mean(NF.field$Elongation, na.rm=TRUE)#1.479181
sd(NF.field$Elongation, na.rm=TRUE) #0.07537064
(sd(NF.field$Elongation, na.rm=TRUE)/ 
  mean(NF.field$Elongation, na.rm=TRUE))*100 #5.09543

mean(NF.museum$Elongation, na.rm=TRUE)#1.463225
sd(NF.museum$Elongation, na.rm=TRUE) #0.06112129
(sd(NF.museum$Elongation, na.rm=TRUE)/ 
  mean(NF.museum$Elongation, na.rm=TRUE))*100 #4.177162


#PolarAsymmetry Mean, SD, CV

#Common Guillemot
mean(CG.field$PolarAsymmetry, na.rm=TRUE)#2.428722
sd(CG.field$PolarAsymmetry, na.rm=TRUE) #0.2964314
(sd(CG.field$PolarAsymmetry, na.rm=TRUE)/ 
  mean(CG.field$PolarAsymmetry, na.rm=TRUE))*100 #12.20524

mean(CG.museum$PolarAsymmetry, na.rm=TRUE)#2.399069
sd(CG.museum$PolarAsymmetry, na.rm=TRUE) #0.3044216
(sd(CG.museum$PolarAsymmetry, na.rm=TRUE)/ 
  mean(CG.museum$PolarAsymmetry, na.rm=TRUE))*100 #12.68916


#Razorbill
mean(R.field$PolarAsymmetry, na.rm=TRUE)#1.916599
sd(R.field$PolarAsymmetry, na.rm=TRUE) #0.1742214
(sd(R.field$PolarAsymmetry, na.rm=TRUE)/ 
  mean(R.field$PolarAsymmetry, na.rm=TRUE))*100 #9.090133

mean(R.museum$PolarAsymmetry, na.rm=TRUE)#1.954385
sd(R.museum$PolarAsymmetry, na.rm=TRUE) #0.2012409
(sd(R.museum$PolarAsymmetry, na.rm=TRUE)/ 
  mean(R.museum$PolarAsymmetry, na.rm=TRUE))*100 #10.29689


#Northern Fulmar
mean(NF.field$PolarAsymmetry, na.rm=TRUE)#1.527365
sd(NF.field$PolarAsymmetry, na.rm=TRUE) #0.2864054
(sd(NF.field$PolarAsymmetry, na.rm=TRUE)/ 
  mean(NF.field$PolarAsymmetry, na.rm=TRUE))*100 #18.7516

mean(NF.museum$PolarAsymmetry, na.rm=TRUE)#1.578958
sd(NF.museum$PolarAsymmetry, na.rm=TRUE) #0.212082
(sd(NF.museum$PolarAsymmetry, na.rm=TRUE)/ 
  mean(NF.museum$PolarAsymmetry, na.rm=TRUE))*100 #13.43177


#volcc Mean, SD, CV

#Common Guillemot
mean(CG.field$volcc, na.rm=TRUE)#94.57781
sd(CG.field$volcc, na.rm=TRUE) #7.52069
(sd(CG.field$volcc, na.rm=TRUE)/ 
  mean(CG.field$volcc, na.rm=TRUE))*100 #7.951854

mean(CG.museum$volcc, na.rm=TRUE)#94.41083
sd(CG.museum$volcc, na.rm=TRUE) #6.987621
(sd(CG.museum$volcc, na.rm=TRUE)/ 
  mean(CG.museum$volcc, na.rm=TRUE))*100 #7.401292


#Razorbill
mean(R.field$volcc, na.rm=TRUE)#81.4633
sd(R.field$volcc, na.rm=TRUE) #6.3721
(sd(R.field$volcc, na.rm=TRUE)/ 
  mean(R.field$volcc, na.rm=TRUE))*100 #7.822049

mean(R.museum$volcc, na.rm=TRUE)#81.98097
sd(R.museum$volcc, na.rm=TRUE) #6.212219
(sd(R.museum$volcc, na.rm=TRUE)/ 
  mean(R.museum$volcc, na.rm=TRUE))*100 #7.577636


#Northern Fulmar
mean(NF.field$volcc, na.rm=TRUE)#96.73004
sd(NF.field$volcc, na.rm=TRUE) #11.57231
(sd(NF.field$volcc, na.rm=TRUE)/ 
  mean(NF.field$volcc, na.rm=TRUE))*100 #11.96352

mean(NF.museum$volcc, na.rm=TRUE)#97.74711
sd(NF.museum$volcc, na.rm=TRUE) #10.21748
(sd(NF.museum$volcc, na.rm=TRUE)/ 
  mean(NF.museum$volcc, na.rm=TRUE))*100 #10.45297

############################################################
#STATISTICAL ANALYSES
############################################################

###
#ANOVA COMPARING DIFFERENT YEARS OF SKOMER EGGS
#again, this has been performed to see if it is justified/appropriate to just
#collate all the fieldly collected samples from different years together
#to compare with the museum sampling type set.
###

#CG
CG.Pointedness <- aov(Pointedness ~ separated.groupings, data = CG.field)
summary(CG.Pointedness) #F(4,274) = 0.910 p = 0.459
TukeyHSD(CG.Pointedness, "separated.groupings", ordered = FALSE)

CG.Elongation <- aov(Elongation ~ separated.groupings, data = CG.field)
summary(CG.Elongation) # F(4,274) = 1.573 p = 0.182
TukeyHSD(CG.Elongation, "separated.groupings", ordered = FALSE)

CG.PolarAsymmetry <- aov(PolarAsymmetry ~ separated.groupings, data = CG.field)
summary(CG.PolarAsymmetry) # F(4,274) = 0.632 p = 0.640
TukeyHSD(CG.PolarAsymmetry, "separated.groupings", ordered = FALSE)

#R
R.Pointedness <- aov(Pointedness ~ separated.groupings, data = R.field)
summary(R.Pointedness) #F(3,54) = 1.171 p = 0.329
TukeyHSD(R.Pointedness, "separated.groupings", ordered = FALSE)

R.Elongation <- aov(Elongation ~ separated.groupings, data = R.field)
summary(R.Elongation) #F(3,54) = 0.414 p = 0.743
TukeyHSD(R.Elongation, "separated.groupings", ordered = FALSE)

R.PolarAsymmetry <- aov(PolarAsymmetry ~ separated.groupings, data = R.field)
summary(R.PolarAsymmetry) #F(3,54) = 0.510 p = 0.677
TukeyHSD(R.PolarAsymmetry, "separated.groupings", ordered = FALSE)

#No significant difference between years
#Hence, we proceed with statistical testing using the collated field collection data.


#MAIN MANUSCRIPT STATISTICAL TESTS#

###
#Compare means#
###

#CG
t.test(Pointedness ~ collection.type, data = CG) #t = 3.77, df = 185.16, p < 0.001, 95% CL = -0.009, -0.003
t.test(Elongation ~ collection.type, data = CG) #t = 0.47, df = 173.93, p = 0.64, 95% CL = -0.012, 0.020
t.test(PolarAsymmetry ~ collection.type, data = CG) #t = 0.87, df = 195.04, p = 0.38, 95% CL = -0.037, 0.097
t.test(volcc ~ collection.type, data = CG) #t = 0.21, df = 213.81, p = 0.84, 95% CL = -1.418, 1.752

#R
t.test(Pointedness ~ collection.type, data = R) #t = 0.41, df = 119.89, p = 0.68, 95% CL = -0.006, 0.004
t.test(Elongation ~ collection.type, data = R) #t = 1.69, df = 120.48, p = 0.09, 95% CL = -0.003, 0.040
t.test(PolarAsymmetry ~ collection.type, data = R) #t = 1.20, df = 133.34, p = 0.23, 95% CL = -0.100, 0.025
t.test(volcc ~ collection.type, data = R) #t = 0.48, df = 120.34, p = 0.63, 95% CL = -2.640, 1.604

#NF
t.test(Pointedness ~ collection.type, data = NF) #t = 0.38, df = 53.57, p = 0.70, 95% CL = -0.009, 0.013
t.test(Elongation ~ collection.type, data = NF) #t = 0.93, df = 60.74, p = 0.35, 95% CL = -0.018, 0.050
t.test(PolarAsymmetry ~ collection.type, data = NF) #t = 0.82, df = 58.87, p = 0.41, 95% CL = -0.177, 0.074
t.test(volcc ~ collection.type, data = NF) #t = 0.37, df = 61.77, p = 0.71, 95% CL = -6.465, 4.431


###
#Testing the differences between the CV of the two sample sets
###

library("cvequality")

#CG collated
#Krishnamoorthy and Lee's (2014) modified signed-likelihood ratio test:
set.seed(10) #function to keep result output consistent
mslr_test(nr = 1e4, CG$Pointedness, CG$collection.type) #mslrt = 0.90, p = 0.34

set.seed(10) #function to keep result output consistent
mslr_test(nr = 1e4, CG$Elongation, CG$collection.type) #mslrt = 4.39, p = 0.04

set.seed(10) #function to keep result output consistent
mslr_test(nr = 1e4, CG$PolarAsymmetry, CG$collection.type) #mslrt = 0.20, p = 0.65

set.seed(10) #function to keep result output consistent
mslr_test(nr = 1e4, CG$volcc, CG$collection.type) #mslrt = 0.83, p = 0.36

#R collated
#Krishnamoorthy and Lee's (2014) modified signed-likelihood ratio test:
set.seed(10) #function to keep result output consistent
mslr_test(nr = 1e4, R$Pointedness, R$collection.type) #mslrt = 0.06, p = 0.80

set.seed(10) #function to keep result output consistent
mslr_test(nr = 1e4, R$Elongation, R$collection.type) #mslrt = 0.01, p = 0.93

set.seed(10) #function to keep result output consistent
mslr_test(nr = 1e4, R$PolarAsymmetry, R$collection.type) #mslrt = 1.06, p = 0.30

set.seed(10) #function to keep result output consistent
mslr_test(nr = 1e4, R$volcc, R$collection.type) #mslrt = 0.06, p = 0.81

#NF collated
#Krishnamoorthy and Lee's (2014) modified signed-likelihood ratio test:
set.seed(10) #function to keep result output consistent
mslr_test(nr = 1e4, NF$Pointedness, NF$collection.type) #mslrt = 6.96, p < 0.01
#is an outlier data point driving this result?
#checking if this is the case

set.seed(10) #function to keep result output consistent
mslr_test(nr = 1e4, NF.remove.outlier$Pointedness, NF.remove.outlier$collection.type) #mslrt = 3.14, p = 0.08
#would appear to be the case

set.seed(10) #function to keep result output consistent
mslr_test(nr = 1e4, NF$Elongation, NF$collection.type) #mslrt = 1.20, p = 0.27

set.seed(10) #function to keep result output consistent
mslr_test(nr = 1e4, NF$PolarAsymmetry, NF$collection.type) #mslrt = 3.22, p = 0.07

set.seed(10) #function to keep result output consistent
mslr_test(nr = 1e4, NF$volcc, NF$collection.type) #mslrt = 0.54, p = 0.46

###
#Test whether two samples distribution is different
#two sample Kolmogorov-Smirnov test
###

#CG
ks.test(CG.field$Pointedness, CG.museum$Pointedness)#D = 0.25, p < 0.001
ks.test(CG.field$Elongation, CG.museum$Elongation) #D = 0.09, p = 0.55
ks.test(CG.field$PolarAsymmetry, CG.museum$PolarAsymmetry) #D = 0.09, p = 0.56
ks.test(CG.field$volcc, CG.museum$volcc) #D = 0.10, p = 0.38

#R 
ks.test(R.field$Pointedness, R.museum$Pointedness) #D = 0.12, p = 0.65
ks.test(R.field$Elongation, R.museum$Elongation) #D = 0.16, p = 0.28
ks.test(R.field$PolarAsymmetry, R.museum$PolarAsymmetry) #D = 0.14, p = 0.50
ks.test(R.field$volcc, R.museum$volcc) #D = 0.11, p = 0.77

#NF
ks.test(NF.field$Pointedness, NF.museum$Pointedness) #D = 0.12, p = 0.94
ks.test(NF.field$Elongation, NF.museum$Elongation) #D = 0.27, p = 0.16
ks.test(NF.field$PolarAsymmetry, NF.museum$PolarAsymmetry) #D = 0.22, p = 0.36
ks.test(NF.field$volcc, NF.museum$volcc) #D = 0.18, p = 0.56



